@@ -151,7 +151,6 @@ impl<'b, B: ?Sized, O, S: ?Sized> Boa<'b, B, O, S> {
     assert_matches::assert_matches!(s, BoaStr::Owned(_));
     ```
     */
-    #[cfg(feature = "unstable")] // reason: Upgrading the lifetime may be used rarely.
     #[inline]
     pub fn into_static(self) -> Boa<'static, B, O, S>
     where
@@ -206,7 +205,7 @@ impl<'b, B: ?Sized, O, S: ?Sized> Boa<'b, B, O, S> {
     ```
     */
     // unstable reason:
-    // Upgrading the lifetime may be used rarely.
+    // Downgrading the lifetime may be used rarely.
     // Compatibility may be broken in rare cases, when BorrowedArc is stabilized.
     #[cfg(feature = "unstable")]
     #[inline]
@@ -646,3 +645,15 @@ impl<'b> From<Boa<'b, Path, PathBuf>> for PathBuf {
         x.into_owned()
     }
 }
+
+impl<'b, B, O, S, T, const N: usize> From<[T; N]> for Boa<'b, B, O, S>
+where
+    B: ?Sized,
+    O: From<[T; N]>,
+    S: ?Sized,
+{
+    #[inline]
+    fn from(x: [T; N]) -> Self {
+        Self::Owned(x.into())
+    }
+}
