@@ -173,7 +173,6 @@ impl<'b, B: ?Sized, O, S: ?Sized> Boar<'b, B, O, S> {
     assert_matches::assert_matches!(s, BoarStr::Owned(_));
     ```
     */
-    #[cfg(feature = "unstable")] // reason: Upgrading the lifetime may be used rarely.
     #[inline]
     pub fn into_static(self) -> Boar<'static, B, O, S>
     where
@@ -182,8 +181,10 @@ impl<'b, B: ?Sized, O, S: ?Sized> Boar<'b, B, O, S> {
         match self {
             Self::Borrowed(x) => Boar::Owned(x.to_owned()),
             Self::Owned(x) => Boar::Owned(x),
+            #[cfg(feature = "unstable")]
             Self::BorrowedArc(x) => Boar::Arc(x.clone()),
             Self::Arc(x) => Boar::Arc(x),
+            #[cfg(feature = "unstable")]
             Self::BorrowedRc(x) => Boar::Rc(x.clone()),
             Self::Rc(x) => Boar::Rc(x),
         }
@@ -211,7 +212,7 @@ impl<'b, B: ?Sized, O, S: ?Sized> Boar<'b, B, O, S> {
     ```
     */
     // unstable reason:
-    // Upgrading the lifetime may be used rarely.
+    // Downgrading the lifetime may be used rarely.
     // Compatibility may be broken in rare cases, when BorrowedArc is stabilized.
     #[cfg(feature = "unstable")]
     #[inline]
@@ -674,3 +675,15 @@ impl<'b> From<Boar<'b, Path, PathBuf>> for PathBuf {
         x.into_owned()
     }
 }
+
+impl<'b, B, O, S, T, const N: usize> From<[T; N]> for Boar<'b, B, O, S>
+where
+    B: ?Sized,
+    O: From<[T; N]>,
+    S: ?Sized,
+{
+    #[inline]
+    fn from(x: [T; N]) -> Self {
+        Self::Owned(x.into())
+    }
+}
